<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    North_Checkout
 * @subpackage North_Checkout/admin
 * @author     North Plugins <hello@northcheckout.com>
 */

if ( ! class_exists( 'North_Deactivate_Popup' ) ) :
    /**
     * North_Deactivate_Popup Class.
     *
     * @since 1.2.0
     */
    class North_Deactivate_Popup {
        /**
         * North_Deactivate_Popup
         *
         * @var $instance
         **/
        private static $instance = null;

        /**
         * Google endpoint which collect data form popup
         *
         * @var string
         **/
        private $google_endpoint = 'https://script.google.com/macros/s/AKfycbwfcpJ4vd-uMHfyyViSZHkLpqKoQD7wuqjD9q-dPl5snCHi88c/exec';

        /**
         * Create $instance
         *
         * @return object
         *
         * @access public
         */
        public static function init() {
            if ( is_null( self::$instance ) ) {
                self::$instance = new North_Deactivate_Popup();
            }
            return self::$instance;
        }
        /**
         * Define menu in admin
         **/
        private function __construct() {
            add_action( 'current_screen', function () {
                if ( ! $this->is_plugins_screen() ) {
                    return;
                }

                add_action( 'admin_enqueue_scripts', [ $this, 'enqueue_feedback_dialog_scripts' ] );
            } );

            // Ajax.
            add_action( 'wp_ajax_north_deactivate_feedback', [ $this, 'ajax_north_deactivate_feedback' ] );
        }
        /**
         * Enqueue feedback dialog scripts.
         *
         * Registers the feedback dialog scripts and enqueues them.
         *
         * @since 1.2.0
         * @access public
         */
        public function enqueue_feedback_dialog_scripts() {
            add_action( 'admin_footer', [ $this, 'print_deactivate_feedback_dialog' ] );

            wp_enqueue_style( 'north-checkout-admin-feedback-css',  plugin_dir_url( __FILE__ ) . 'css/north-checkout-admin-deactivate-popup.css', array(), null, 'all' );

            wp_register_script(
                'north-admin-feedback',
                plugin_dir_url( __FILE__ ) . 'js/north-checkout-admin-deactivate-popup.js',
                [
                    'jquery',
                ],
                null,
                true
            );

            wp_enqueue_script( 'north-admin-feedback' );

            wp_enqueue_script( 'jquery-ui-dialog' );
            wp_enqueue_style( 'wp-jquery-ui-dialog' );
        }

        /**
         * Print deactivate feedback dialog.
         *
         * Display a dialog box to ask the user why he deactivated North Checkout.
         *
         * Fired by `admin_footer` filter.
         *
         * @since 1.2.0
         * @access public
         */
        public function print_deactivate_feedback_dialog() {
            $deactivate_reasons = [
                'specific_feature' => [
                    'title' => __( 'I need a specific feature that plugin doesn\'t support', 'north-checkout' ),
                    'input_placeholder' => __( 'What features are missing?', 'north-checkout'),
                ],
                'found_a_better_plugin' => [
                    'title' => __( 'I found a better plugin', 'north-checkout' ),
                    'input_placeholder' => __( 'What\'s the plugin\'s name?', 'north-checkout'),
                ],
                'broke_site' => [
                    'title' => __( 'The plugin broke my site', 'north-checkout' ),
                    'input_placeholder' => '',
                ],
                'no_longer_needed' => [
                    'title' => __( 'I no longer need the plugin', 'north-checkout' ),
                    'input_placeholder' => '',
                ],
                'short_period' => [
                    'title' => __( 'I only needed the plugin for a short period', 'north-checkout' ),
                    'input_placeholder' => '',
                ],
                'couldnt_get_the_plugin_to_work' => [
                    'title' => __( 'The plugin suddenly stopped working', 'north-checkout' ),
                    'input_placeholder' => '',
                ],

                'temporary_deactivation' => [
                    'title' => __( 'It\'s a temporary deactivation', 'north-checkout' ),
                    'input_placeholder' => '',
                ],
                'other' => [
                    'title' => __( 'Other', 'north-checkout' ),
                    'input_placeholder' => __( 'Kindly tell us the reason so we can improve.', 'north-checkout' ),
                ],
            ];

            ?>
            <div id="north-deactivate-feedback-dialog-wrapper" title="<?php echo esc_html( __( 'Quick Feedback', 'north-checkout' ) ); ?>">
                <form id="north-deactivate-feedback-dialog-form" method="post">
                    <?php
                    wp_nonce_field( '_north_deactivate_feedback_nonce' );
                    ?>
                    <input type="hidden" name="action" value="north_deactivate_feedback" />
                    <div class="north-deactivate-feedback-dialog-form-caption">
                        <h3><?php echo esc_html( __( 'If you have a moment, please let us know why you are deactivating:', 'north-checkout' ) ); ?><h3>
                    </div>
                    <div id="north-deactivate-feedback-dialog-form-body">
                        <?php foreach ( $deactivate_reasons as $reason_key => $reason ) : ?>
                            <div class="north-deactivate-feedback-dialog-input-wrapper">
                                <label for="north-deactivate-feedback-<?php echo esc_attr( $reason_key ); ?>" class="north-deactivate-feedback-dialog-label">
                                    <input id="north-deactivate-feedback-<?php echo esc_attr( $reason_key ); ?>" class="north-deactivate-feedback-dialog-input" type="radio" name="reason_key" value="<?php echo esc_attr( $reason_key ); ?>" />
                                    <?php echo esc_html( $reason['title'] ); ?>
                                    <?php if ( ! empty( $reason['input_placeholder'] ) ) : ?>
                                        <textarea class="north-feedback-text" type="text" name="reason_message_<?php echo esc_attr( $reason_key ); ?>" placeholder="<?php echo esc_attr( $reason['input_placeholder'] ); ?>"><?php echo esc_html( $reason['title'] ); ?></textarea>
                                    <?php endif; ?>
                                </label>
                            </div>
                        <?php endforeach; ?>
                    </div>
                </form>
            </div>
            <?php
        }

        /**
         * @since 1.2.0
         * @access private
         */
        private function is_plugins_screen() {
            return in_array( get_current_screen()->id, [ 'plugins', 'plugins-network' ] );
        }

        /**
         * Ajax north deactivate feedback.
         *
         * Send the user feedback when North Checkout is deactivated.
         *
         * Fired by `wp_ajax_north_deactivate_feedback` action.
         *
         * @since 1.2.0
         * @access public
         */
        public function ajax_north_deactivate_feedback() {
            if ( ! isset( $_POST['_wpnonce'] ) || ! wp_verify_nonce( sanitize_text_field( $_POST['_wpnonce'] ), '_north_deactivate_feedback_nonce' ) ) {
                wp_send_json_error();
            }

            $reason_text = '1';
            $reason_key = '';

            if ( ! empty( $_POST['reason_key'] ) ) {
                $reason_key = sanitize_text_field( $_POST['reason_key'] );
            }

            if ( ! empty( $_POST[ "reason_message_{$reason_key}" ] ) ) {
                $reason_text = sanitize_text_field( $_POST[ "reason_message_{$reason_key}" ] );
            }

            $reason = ucfirst(str_replace('_', ' ', $reason_key));

            wp_remote_get( $this->google_endpoint .'?p1=' . $reason . '&p2=' . $reason_text );

            wp_send_json_success();
        }

    }
    North_Deactivate_Popup::init();
endif;