<?php


/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       https://northplugins.com/
 * @since       1.0
 *
 * @package    North_Checkout
 * @subpackage North_Checkout/admin/templates/tabs
 */

if( isset($_GET['id']) ) { // phpcs:ignore WordPress.Security.NonceVerification.Recommended
    $coupon_id = sanitize_text_field( $_GET['id'] );  // phpcs:ignore WordPress.Security.NonceVerification.Recommended
    $coupon = new North_Checkout_Coupon($coupon_id);
}else {
    $coupon = new North_Checkout_Coupon();
}

if( isset($_POST['submit_create']) || isset($_POST['submit_update']) ) { // phpcs:ignore WordPress.Security.NonceVerification.Missing
    $coupon_args = $_POST; // phpcs:ignore WordPress.Security.NonceVerification.Missing
    $status = 'active';

    unset($coupon_args["coupon_name"]);
    unset($coupon_args["submit_create"]);
    unset($coupon_args["submit_update"]);

    if( isset($coupon_args["coupon_status"]) ) {
        $status = $coupon_args["coupon_status"];
        unset($coupon_args["coupon_status"]);
    }

    $coupon_name = isset($_POST["coupon_name"]) && !empty($_POST["coupon_name"]) ? sanitize_text_field( $_POST["coupon_name"] ) : 'Coupon name'; // phpcs:ignore WordPress.Security.NonceVerification.Missing
}

?>

<div class="wrap north-settings">

    <div class="north-tab-wrapper">
        <?php $this->plugin_tabs(); ?>
    </div>

    <?php do_action( 'north_checkout_notices' ); ?>

    <div id="wpmdb-main">

        <div id="coupons-tab" class="coupons-tab content-tab">

            <?php
            if(isset($_POST['submit_create'])) {  // phpcs:ignore WordPress.Security.NonceVerification.Missing
                $coupon_response = $coupon->create_coupon($coupon_name, $status, $coupon_args);

                if ( is_wp_error($coupon_response) ){
                    echo '<div class="north-error" style="display: block;">' . esc_html( $coupon_response->get_error_message() ) . '</div>';
                }else {
                    $redirect_url = $this->options_url . "-coupons"; ?>
                    <script type="text/javascript">
                        document.location.href = '<?php echo $redirect_url; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>';
                    </script>
                    <?php
                }
            }
            if(isset($_POST['submit_update'])) { // phpcs:ignore WordPress.Security.NonceVerification.Missing
                $coupon_response = $coupon->update_coupon($coupon_id, $coupon_name, $status, $coupon_args);

                if ( is_wp_error($coupon_response) ){
                    echo '<div class="north-error" style="display: block;">' . esc_html( $coupon_response->get_error_message() ) . '</div>';
                }else {
                    echo '<div class="north-success" style="display: block;">Coupon was successfully updated!</div>';
                }
            }
            ?>

            <?php if( isset($_GET['action']) ) : // phpcs:ignore WordPress.Security.NonceVerification.Recommended 

                $args = array(
                    'coupon_name'              => null,
                    'coupon_type'              => 'Subscription',
                    'coupon_trial_type'        => null,
                    'coupon_trial_count'       => null,
                    'coupon_frequency'         => 'week',
                    'coupon_frequency_sub'     => 'week',
                    'coupon_start_price'       => null,
                    'coupon_payment_number'    => null,
                    'coupon_price'             => null,
                    'coupon_currency'          => null,
                    'bump_trial_type'           => null,
                    'bump_trial_count'          => null,
                    'bump_frequency'            => 'week',
                    'bump_frequency_sub'        => 'week',
                    'bump_start_price'          => null,
                    'bump_payment_number'       => null,
                    'bump_price'                => null,
                    'bump_currency'             => null,
                );

                if(!empty($coupon_id)) {
                    $args['coupon_name'] = get_the_title($coupon_id);
                    $args['coupon_price'] = $coupon->get_price();
                    $args['coupon_type'] = !empty($coupon->get_type()) ? $coupon->get_type() : 'fixed';
                    $args['coupon_limit'] = $coupon->get_limit();
                    $args['coupon_status'] = get_post_status($coupon_id);
                }
                
                ?>

                <div class="coupons-tab__head">
                    <h2>Coupons</h2>
                    <a href="<?php echo esc_url( $this->options_url ) . '-coupons'; ?>" class="btn btn-grey">< Back</a>

                    <?php if ($_GET['action'] != 'add') : // phpcs:ignore WordPress.Security.NonceVerification.Recommended ?>
                        <a href="<?php echo esc_url( $this->options_url ) . '-coupons&action=add'; ?>" class="btn">+ Add Coupon</a>
                    <?php endif; ?>
                </div>

                <?php $coupon->template('coupon-form', 'coupon', $args); ?>

            <?php else: $coupons = $coupon->get_coupons(8, true); ?>

                <?php if($coupons === NULL) : ?>
                    <div class="coupon-first-msg">
                        <h1>Create your first coupon</h1>
                        <a href="<?php echo esc_url(get_site_url()) . '/wp-admin/admin.php?page=north-checkout-coupons&amp;action=add'; ?>" class="btn">Create Coupon</a>
                    </div>
                <?php else:; ?>
                    <div class="coupons-tab__head">
                        <h2>Coupons</h2>
                        <?php if (isset($_GET['action'])) : // phpcs:ignore WordPress.Security.NonceVerification.Recommended ?>
                            <a href="<?php echo esc_url( $this->options_url ) . '-coupons'; ?>" class="btn btn-grey">< Back</a>

                            <?php if ($_GET['action'] != 'add') : // phpcs:ignore WordPress.Security.NonceVerification.Recommended?>
                                <a href="<?php echo esc_url( $this->options_url ) . '-coupons&action=add'; ?>" class="btn">+ Add Coupon</a>
                            <?php endif; ?>

                        <?php else:; ?>
                            <a href="<?php echo esc_url( $this->options_url ) . '-coupons&action=add'; ?>" class="btn">+ Add Coupon</a>
                        <?php endif; ?>
                    </div>
                    <div id="coupon-list" class="coupons-tab__body">
                        <div class="coupon-list__head">
                            <h4 class="coupon-column-1">Coupon name</h4>
                            <h4 class="coupon-column-2">Price</h4>
                            <h4 class="coupon-column-3">Status</h4>
                            <h4 class="coupon-column-4">Limit</h4>
                            <h4 class="coupon-column-5">Edit Button</h4>
                            <h4 class="coupon-column-6">Delete Button</h4>
                        </div>
                        <div class="item-container coupon-list__body">
                            <?php echo $coupon->get_coupons(); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped?>
                        </div>
                    </div>
                    <div class="coupons-tab__footer">
                        <div class="north-error">All coupons loaded</div>
                        <?php $coupon->get_pagination(); ?>
                    </div>
                <?php endif; ?>
            <?php endif; ?>

        </div> <!-- end .coupons-tab -->

    </div>
    <div class="modal modal-delete">
        <h3>Are you sure?</h3>
        <a class="btn delete" data-id="" data-type="">Yes</a>
        <a class="btn btn-grey cancel">No</a>
        <div class="loader delete-loader"></div>
    </div>
    <!-- end #wpmdb-main -->

</div> <!-- end .wrap -->
