<?php
/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       https://northplugins.com/
 * @since       1.0
 *
 * @package    North_Checkout
 * @subpackage North_Checkout/admin/templates/tabs
 */

$order_id = null;
$customer_name = null;
$customer_phone = null;
$customer_email = null;
$customer_address = null;
$product_name = null;
$product_currency = null;
$product_subtotal = null;
$product_transaction_id = null;
$bump_name = null;
$bump_subtotal = null;
$bump_transaction_id = null;
$card_last_four = null;
$card_brand = null;
$total = null;
$flex_info = null;
$product_success = null;
$bump_success = null;

if (isset($_GET['view']) && !empty($_GET['view'])) { // phpcs:ignore WordPress.Security.NonceVerification.Recommended
    $order_id = sanitize_text_field( $_GET['view'] ); // phpcs:ignore WordPress.Security.NonceVerification.Recommended
    $north_order = new North_Checkout_Order($order_id);
    $customer_name = get_post_meta($order_id, 'customer_name', true);
    $customer_phone = get_post_meta($order_id, 'customer_phone', true);
    $customer_email = get_post_meta($order_id, 'customer_email', true);
    $customer_address = json_decode(get_post_meta($order_id, 'customer_address', true));
    $product_name = get_post_meta($order_id, 'product_name', true);
    $product_currency = get_post_meta($order_id, 'product_currency', true);
    $product_price = get_post_meta($order_id, 'product_price', true);
    $product_quantity = get_post_meta($order_id, 'product_quantity', true) ? get_post_meta($order_id, 'product_quantity', true) : 1;
    $product_subtotal = get_post_meta($order_id, 'product_subtotal', true);
    $product_transaction_id = get_post_meta($order_id, 'product_trans_id', true);
    $bump_name = get_post_meta($order_id, 'bump_name', true);
    $bump_subtotal = get_post_meta($order_id, 'bump_subtotal', true);
    $bump_transaction_id = get_post_meta($order_id, 'bump_trans_id', true);
    $card_last_four = get_post_meta($order_id, 'card_last_four', true);
    $card_brand = get_post_meta($order_id, 'card_brand', true);
    $payment_method = get_post_meta($order_id, 'payment_method', true);
    $subtotal = get_post_meta($order_id, 'subtotal', true);
    $total = get_post_meta($order_id, 'total', true);
    $flex_info = json_decode(get_post_meta($order_id, 'flex_info', true));
    $product_success = get_post_meta($order_id, 'product_payment_status', true);
    $bump_success = get_post_meta($order_id, 'bump_payment_status', true);
    $coupon = get_post_meta($order_id, 'coupon', true) ? get_post_meta($order_id, 'coupon', true) : '';
    $coupon_price = null;
    $coupon_id = null;

    if(!empty($coupon)) {
        $coupon = is_object($coupon) ? $coupon->post_title : $coupon;
        $coupon = get_page_by_title($coupon, OBJECT, 'north_coupon');
        $coupon_id = $coupon->ID;
        $coupon_instance = new North_Checkout_Coupon($coupon_id);
        $coupon_price = $coupon_instance->get_price_html();
    }

    $product_transaction_text = 'View transaction';
    $product_success_error = '';

    if($product_success === 'false') {
        $product_transaction_text = 'Payment Error';
        $product_success_error = 'payment-error';
    }

    $bump_transaction_text = 'View transaction';
    $bump_success_error = '';

    if($bump_success === 'false') {
        $bump_transaction_text = 'Payment Error';
        $bump_success_error = 'payment-error';
    }

}else {
    $north_order = new North_Checkout_Order();
}

?>
<div class="wrap north-settings">

    <div class="north-tab-wrapper">
        <?php $this->plugin_tabs(); ?>
    </div>

    <?php do_action( 'north_checkout_notices' ); ?>

    <div id="wpmdb-main">
        <div id="orders-tab" class="orders-tab content-tab">
            <?php if (!empty($order_id)) : ?>
                <?php if (($north_post_type = get_post_type($order_id)) && $north_post_type === 'north_order') : ?>
                    <div class="order-overview">
                        <div class="order-overview__left">
                            <div class="overview-header">
                                <a href="<?php echo esc_url( site_url() ) . '/wp-admin/admin.php?page=north-checkout-orders'; ?>" class="btn back-btn"></a>
                                <h2>Order Overview</h2>
                            </div>
                            <div class="overview-info">
                                <div class="overview-info__cus">
                                    <div>
                                        <h4>Customer Name</h4>
                                        <?php echo esc_html( $customer_name ); ?>
                                        <br>
                                        <br>
                                        <h4>Customer Phone</h4>
                                        <a href="tel:<?php echo esc_html( preg_replace('/[^0-9]/', '',  $customer_phone ) ); ?>"><?php echo esc_html( $customer_phone ); ?></a>
                                    </div>
                                    <div>
                                        <?php echo get_the_date('m/d/Y', $order_id); ?><br>
                                        <a href="mailto:<?php echo esc_html( $customer_email ); ?>"><?php echo esc_html( $customer_email ); ?></a>
                                    </div>
                                </div>
                                <div class="overview-info__stripe">
                                    <div>
                                        <h4>Shipping Address</h4>
                                        <?php
                                        if( !empty($customer_address) ) {
                                            echo esc_html( $customer_address->full ) . '<br>';
                                            echo !empty($customer_address->line_2) ? esc_html( $customer_address->line_2 ) . '<br>' : '';
                                            echo esc_html( $customer_address->city ) . ', ' . esc_html( $customer_address->state ) . ' ' . esc_html( $customer_address->zip ) . '<br>';
                                            echo esc_html( $customer_address->country ) . '<br>';
                                        }else {
                                            echo '-';
                                        }
                                        ?>
                                    </div>
                                    <div>
                                        <h4>Payment Method</h4>
                                        <?php if($payment_method === 'Free') : ?>
                                            <?php echo esc_html(  $payment_method ); ?><br>
                                        <?php else: ?>
                                        <?php echo esc_html( $card_brand ); ?> (Via <?php echo esc_html(  $payment_method ); ?>)<br>
                                        <?php if($payment_method === 'Stripe') : ?>
                                            <span class="pay-card">**** **** **** <?php echo esc_html(  $card_last_four ); ?> <span class="pay-card-image <?php echo esc_html( strtolower(str_replace(' ', '_', $card_brand)) ); ?>"></span></span>
                                        <?php endif; ?>
                                        <?php endif; ?>
                                    </div>
                                </div>
                            </div>

                            <?php if( !empty($flex_info) ) : $i = 0; ?>

                                <div class="overview-header">
                                    <h2>Other Information</h2>
                                </div>

                                <div class="overview-flex">

                                    <?php foreach( $flex_info as $key => $value ) : ?>

                                        <div class="overview-flex__block">
                                            <h4><?php echo esc_html( ucwords(str_replace('_', ' ',substr($key, 9))) ); ?></h4>
                                            <p><?php echo esc_html( $value ); ?></p>
                                        </div>

                                    <?php endforeach; ?>

                                </div>

                            <?php endif; ?>

                            <!--                    <div class="overview-header">-->
                            <!--                        <h2>History</h2>-->
                            <!--                    </div>-->
                            <!--                    <div class="overview-history">-->
                            <!--                        <div class="overview-history__line">-->
                            <!--                            <div class="history-date">MM/DD/YYYY,12:23PM</div>-->
                            <!--                            <div class="history-action">Created the order</div>-->
                            <!--                            <div class="history-type"><a href="#">Zapier</a></div>-->
                            <!--                        </div>-->
                            <!--                        <div class="overview-history__line">-->
                            <!--                            <div class="history-date">MM/DD/YYYY,12:25PM</div>-->
                            <!--                            <div class="history-action">Zapier triggered</div>-->
                            <!--                            <div class="history-type"><a href="#">Stripe</a></div>-->
                            <!--                        </div>-->
                            <!--                        <div class="overview-history__line">-->
                            <!--                            <div class="history-date">MM/DD/YYYY,12:23PM</div>-->
                            <!--                            <div class="history-action">Created the order</div>-->
                            <!--                            <div class="history-type"><a href="#">Zapier</a></div>-->
                            <!--                        </div>-->
                            <!--                    </div>-->
                        </div>
                        <div class="order-overview__right">
                            <div class="overview-header">
                                <h2>Summary</h2>
                            </div>
                            <div class="overview-summary">
                                <div class="overview-summary__line product-line <?php echo $product_success_error; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped?>">
                                    <div class="line-name">1. <?php echo esc_html( $product_name ) . ' ' . $north_order->get_variations_string($order_id); ?> </div> <?php // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped?>
                                    <div class="line-price">
                                        <?php if($payment_method === 'Stripe') : ?>
                                            <a href="https://dashboard.stripe.com/payments/<?php echo esc_html( $product_transaction_id ); ?>" target="_blank" class="view-transaction"><?php echo $product_transaction_text; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></a> |
                                        <?php endif; ?>
                                        <?php echo esc_html( North_Checkout_Admin::formatted_price($product_price, false, $product_currency) . ' x ' . $product_quantity . ' = ' . North_Checkout_Admin::formatted_price($product_price * $product_quantity, false, $product_currency) ); ?>
                                    </div>
                                </div>
                                <?php if (!empty($bump_name)) : ?>
                                    <div class="overview-summary__line product-line <?php echo $bump_success_error; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped?>">
                                        <div class="line-name">2. Order Bump: <?php echo esc_html( $bump_name ); ?></div>
                                        <div class="line-price"><a href="https://dashboard.stripe.com/payments/<?php echo esc_html( $bump_transaction_id ); ?>" target="_blank" class="view-transaction"><?php echo $bump_transaction_text; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></a> | <?php echo esc_html( North_Checkout_Admin::formatted_price($bump_subtotal, false, $product_currency) ); ?></div>
                                    </div>
                                <?php endif; ?>

                                <hr>
                                <div class="total-line">
                                    <?php if (!empty($coupon_id)) : ?>
                                        <div class="overview-summary__line">
                                            <div>Subtotal</div>
                                            <div class="line-price"><?php echo esc_html(North_Checkout_Admin::formatted_price($subtotal, false, $product_currency)); ?></div>
                                        </div>
                                        <div class="overview-summary__line">
                                            <div>Discount</div>
                                            <div class="line-price"><?php echo $coupon->post_title . ' ( - ' . $coupon_price . ' )'; ?></div>
                                        </div>
                                        <hr>
                                    <?php endif; ?>
                                    <div class="overview-summary__line">
                                        <div>Total</div>
                                        <div class="line-price"><?php echo esc_html(North_Checkout_Admin::formatted_price($total, false, $product_currency)); ?></div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                <?php else:; ?>
                    Order not found!
                <?php endif; ?>
            <?php else:; ?>
                <?php do_action('north_before_orders_list_head'); ?>
                <div class="orders-tab__head">
                    <form id="orders-filter" class="filter-form orders-filter" method="POST">
                        <input type="text" name="filter_name" id="filter_name" class="filter-field" placeholder="Search by #...">
                        <input type="text" name="filter_customer" id="filter_customer" class="filter-field" placeholder="Search by customer...">
                        <input type="submit" name="submit_filter" id="submit_filter" value="Search">
                        <div class="loader filter-loader load-more__loader"></div>
                    </form>
                </div>
                <?php do_action('north_after_orders_list_head'); ?>
                <?php do_action('north_before_orders_list_body'); ?>
                <div id="order-list" class="orders-tab__body">
                    <div class="order-list__head">
                        <h4 class="order-column-1">Order #</h4>
                        <h4 class="order-column-2">Customer Name</h4>
                        <h4 class="order-column-3">Products</h4>
                        <h4 class="order-column-4">Qty</h4>
                        <h4 class="order-column-5">Total</h4>
                        <h4 class="order-column-6">Date</h4>
                        <h4 class="order-column-7">Status</h4>
                        <h4 class="order-column-8">Delete</h4>
                    </div>
                    <div class="item-container order-list__body">
                        <?php $north_order->get_orders(); ?>
                    </div>
                </div>
                <?php do_action('north_after_orders_list_body'); ?>
                <?php do_action('north_before_orders_list_footer'); ?>
                <div class="orders-tab__footer">
                    <div class="north-error">All orders loaded</div>
                    <?php $north_order->get_pagination();?>
                </div>
                <?php do_action('north_after_orders_list_footer'); ?>
            <?php endif; ?>

        </div> <!-- end .orders-tab -->

    </div>
    <div class="modal modal-delete">
        <h3>Are you sure?</h3>
        <a class="btn delete" data-id="" data-type="">Yes</a>
        <a class="btn btn-grey cancel">No</a>
        <div class="loader delete-loader"></div>
    </div>
    <!-- end #wpmdb-main -->

</div> <!-- end .wrap -->