<?php


/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       https://northplugins.com/
 * @since       1.0
 *
 * @package    North_Checkout
 * @subpackage North_Checkout/admin/templates/tabs
 */

if( isset($_GET['id']) ) { // phpcs:ignore WordPress.Security.NonceVerification.Recommended
    $product_id = sanitize_text_field( $_GET['id'] );  // phpcs:ignore WordPress.Security.NonceVerification.Recommended
    $product = new North_Checkout_Product($product_id);
}else {
    $product = new North_Checkout_Product();
}

if( isset($_POST['submit_create']) || isset($_POST['submit_update']) ) { // phpcs:ignore WordPress.Security.NonceVerification.Missing
    // Get form data
    $product_args = $_POST; // phpcs:ignore WordPress.Security.NonceVerification.Missing

    unset($product_args["product_name"]);
    unset($product_args["submit_create"]);
    unset($product_args["submit_update"]);

    if( !isset($product_args["reload_bump"]) ) {
        $product_args["reload_bump"] = false;
    }

    if( !isset($product_args["is_variable"]) ) {
        $product_args["is_variable"] = false;
    }

    $product_name = isset($_POST["product_name"]) && !empty($_POST["product_name"]) ? sanitize_text_field( $_POST["product_name"] ) : 'Product name'; // phpcs:ignore WordPress.Security.NonceVerification.Missing
}


?>

<div class="wrap north-settings">

    <div class="north-tab-wrapper">
        <?php $this->plugin_tabs(); ?>
    </div>

    <?php do_action( 'north_checkout_notices' ); ?>

    <div id="wpmdb-main">

        <div id="products-tab" class="products-tab content-tab">

            <?php
            if(isset($_POST['submit_create'])) {  // phpcs:ignore WordPress.Security.NonceVerification.Missing

                $valid = true;
                $message_error = '';
                $product_response = null;

                if(isset($_POST['product_type']) && $_POST['product_type'] === 'Payment Plan') { // phpcs:ignore WordPress.Security.NonceVerification.Missing
                    $payment_number = isset($_POST['product_payment_number']) ? intval($_POST['product_payment_number']) : ''; // phpcs:ignore WordPress.Security.NonceVerification.Missing
                    $product_price = isset($_POST['product_price']) ? floatval($_POST['product_price']) : ''; // phpcs:ignore WordPress.Security.NonceVerification.Missing
                    $product_start_price = isset($_POST['product_start_price']) ? floatval($_POST['product_start_price']) : ''; // phpcs:ignore WordPress.Security.NonceVerification.Missing

                    if ($payment_number < 1) {
                        $valid = false;
                        $message_error .= '<div class="north-error" style="display: block;"><b>Product:</b> Number of payments must be greater than 0</div>';
                    }

                    if ($product_price <= 0) {
                        $valid = false;
                        $message_error .= '<div class="north-error" style="display: block;"><b>Product:</b> Price of product must be greater than 0</div>';
                    }

                    if ($product_start_price < 0) {
                        $valid = false;
                        $message_error .= '<div class="north-error" style="display: block;"><b>Product:</b> First payment of product must be greater than 0</div>';
                    }

                    if ($product_price <= $product_start_price) {
                        $valid = false;
                        $message_error .= '<div class="north-error" style="display: block;"><b>Product:</b> Price of product must be greater than First payment. First payment it\'s part of Product price</div>';
                    }

                    if(isset($_POST['reload_bump']) && $_POST['reload_bump'] === 'on') { // phpcs:ignore WordPress.Security.NonceVerification.Missing
                        $payment_number = isset($_POST['bump_payment_number']) ? intval($_POST['bump_payment_number']) : ''; // phpcs:ignore WordPress.Security.NonceVerification.Missing
                        $product_price = isset($_POST['bump_price']) ? floatval($_POST['bump_price']) : ''; // phpcs:ignore WordPress.Security.NonceVerification.Missing
                        $product_start_price = isset($_POST['bump_start_price']) ? floatval($_POST['bump_start_price']) : ''; // phpcs:ignore WordPress.Security.NonceVerification.Missing

                        if ($payment_number < 1) {
                            $valid = false;
                            $message_error .= '<div class="north-error" style="display: block;"><b>Bump:</b> Number of payments must be greater than 0</div>';
                        }

                        if ($product_price <= 0) {
                            $valid = false;
                            $message_error .= '<div class="north-error" style="display: block;"><b>Bump:</b> Price of product must be greater than 0</div>';
                        }

                        if ($product_start_price <= 0) {
                            $valid = false;
                            $message_error .= '<div class="north-error" style="display: block;"><b>Bump:</b> Price of product must be greater than 0</div>';
                        }

                        if ($product_price <= $product_start_price) {
                            $valid = false;
                            $message_error .= '<div class="north-error" style="display: block;"><b>Bump:</b> Price of product must be greater than First payment. First payment it\'s part of Product price</div>';
                        }
                    }
                }

                if($valid) {
                    $product_response = $product->create_product($product_name, 'active', $product_args);
                }

                if ( is_wp_error($product_response) ){
                    echo '<div class="north-error" style="display: block;">' . esc_html( $product_response->get_error_message() ) . '</div>';
                }elseif( empty($product_response) ){
                    echo $message_error . '<div class="north-error" style="display: block;">Product not created!</div>'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
                }else {
                    $redirect_url = $this->options_url . "-products"; ?>
                    <script type="text/javascript">
                        document.location.href = '<?php echo $redirect_url; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>';
                    </script>
                    <?php
                }
            }
            if(isset($_POST['submit_update'])) { // phpcs:ignore WordPress.Security.NonceVerification.Missing
                $product_response = $product->update_product($product_id, $product_name, 'active', $product_args);

                if ( is_wp_error($product_response) ){
                    echo '<div class="north-error" style="display: block;">' . esc_html( $product_response->get_error_message() ) . '</div>';
                }else {
                    echo '<div class="north-success" style="display: block;">Product was successfully updated!</div>';
                }
            }
            ?>

            <?php if( isset($_GET['action']) ) : // phpcs:ignore WordPress.Security.NonceVerification.Recommended

                $args = array(
                    'product_name'              => null,
                    'product_type'              => 'Subscription',
                    'product_trial_type'        => null,
                    'product_trial_count'       => null,
                    'product_frequency'         => 'week',
                    'product_frequency_sub'     => 'week',
                    'product_start_price'       => null,
                    'product_payment_number'    => null,
                    'product_price'             => null,
                    'product_currency'          => null,
                    'bump_trial_type'           => null,
                    'bump_trial_count'          => null,
                    'bump_frequency'            => 'week',
                    'bump_frequency_sub'        => 'week',
                    'bump_start_price'          => null,
                    'bump_payment_number'       => null,
                    'bump_price'                => null,
                    'bump_currency'             => null,
                );

                if(!empty($product_id)) {
                    $args['product_name'] = get_the_title($product_id);
                    $args['product_price'] = $product->get_price();
                    $args['product_currency'] = North_Checkout_Admin::get_current_currency();
                    $args['product_type'] = !empty($product->get_type()) ? $product->get_type() : 'Subscription';
                    $args['product_quantity'] = $product->get_quantity();
                    $args['variations'] = $product->get_variations();

                    $args['bump_price'] = $product->get_bump_price();
                    $args['bump_currency'] = North_Checkout_Admin::get_current_currency();
                    $args['bump_quantity'] = $product->get_bump_quantity();

                    if($args['product_type'] == 'Subscription') {
                        $args['product_trial_type']     = $product->get_trial_type();
                        $args['product_trial_count']    = $product->get_trial_count();
                        $args['product_frequency_sub']  = $product->get_frequency();
                        $args['product_start_price_sub']    = $product->get_start_price();

                        $args['bump_trial_type']        = $product->get_bump_trial_type();
                        $args['bump_trial_count']       = $product->get_bump_trial_count();
                        $args['bump_frequency_sub']     = $product->get_bump_frequency();
                        $args['bump_start_price_sub']   = $product->get_bump_start_price();
                    }

                    if($args['product_type'] == 'Payment Plan') {
                        $args['product_payment_number'] = $product->get_payment_count();
                        $args['product_frequency']      = $product->get_frequency();
                        $args['product_start_price']    = $product->get_start_price();

                        $args['bump_payment_number'] = $product->get_bump_payment_count();
                        $args['bump_frequency']      = $product->get_bump_frequency();
                        $args['bump_start_price']   = $product->get_bump_start_price();
                    }

                }
                ?>

                <div class="products-tab__head">
                    <h2>Products</h2>
                    <a href="<?php echo esc_url( $this->options_url ) . '-products'; ?>" class="btn btn-grey">< Back</a>

                    <?php if ($_GET['action'] != 'add') : // phpcs:ignore WordPress.Security.NonceVerification.Recommended ?>
                        <a href="<?php echo esc_url( $this->options_url ) . '-products&action=add'; ?>" class="btn">+ Add Product</a>
                    <?php endif; ?>
                </div>

                <?php $product->template('product-form', 'product', $args); ?>

            <?php else: $products = $product->get_products(8, true); ?>

                <?php if(empty(get_option('stripe_private_active')) && empty(get_option('paypal_client_test')) && empty(get_option('paypal_client_live'))) : ?>

                    <?php
                    $state = isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] === 'on' ? "https" : "http";

                    if(isset($_SERVER['HTTP_HOST']) && isset($_SERVER['REQUEST_URI'])) {
                        $state = $state . "://" . sanitize_text_field( wp_unslash( $_SERVER['HTTP_HOST'] ) ) . '/wp-admin/admin.php?page=north-checkout-settings';
                    }

                    echo '<div class="connect-stripe-msg">
                <h1>Please connect your Stripe or PayPal account</h1>
                <p>(Before creating a product)</p>
                <a href="'. esc_url( $state ) .'" class="btn">Add your account</a>
            </div>';
                    ?>

                <?php elseif($products === NULL && (!empty(get_option('stripe_private_active')) || !empty(get_option('paypal_client_test')) || !empty(get_option('paypal_client_live')) )) : ?>
                    <div class="connect-stripe-msg">
                        <h1>Create your first product</h1>
                        <a href="<?php echo esc_url(get_site_url()) . '/wp-admin/admin.php?page=north-checkout-products&amp;action=add'; ?>" class="btn">Create product</a>
                    </div>
                <?php else:; ?>
                    <?php do_action('north_before_product_list_head'); ?>
                    <div class="products-tab__head">
                        <h2>Products</h2>
                        <?php if (isset($_GET['action'])) : // phpcs:ignore WordPress.Security.NonceVerification.Recommended ?>
                            <a href="<?php echo esc_url( $this->options_url ) . '-products'; ?>" class="btn btn-grey">< Back</a>

                            <?php if ($_GET['action'] != 'add') : // phpcs:ignore WordPress.Security.NonceVerification.Recommended?>
                                <a href="<?php echo esc_url( $this->options_url ) . '-products&action=add'; ?>" class="btn">+ Add Product</a>
                            <?php endif; ?>

                        <?php else:; ?>
                            <a href="<?php echo esc_url( $this->options_url ) . '-products&action=add'; ?>" class="btn">+ Add Product</a>
                        <?php endif; ?>
                    </div>
                    <?php do_action('north_after_product_list_head'); ?>
                    <?php do_action('north_before_product_list_body'); ?>
                    <div id="product-list" class="products-tab__body">
                        <div class="product-list__head">
                            <h4 class="product-column-1">Product name</h4>
                            <h4 class="product-column-2">Price</h4>
                            <h4 class="product-column-3">Edit Button</h4>
                            <h4 class="product-column-4">Delete Button</h4>
                            <h4 class="product-column-5"><img src="<?php echo esc_url( plugin_dir_url( __FILE__ ) ) . '../../images/paypal.png'; ?>"></h4>
                            <h4 class="product-column-6"><img src="<?php echo esc_url( plugin_dir_url( __FILE__ ) ) . '../../images/stripe.png'; ?>"></h4>
                        </div>
                        <div class="item-container product-list__body">
                            <?php echo $product->get_products(); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped?>
                        </div>
                    </div>
                    <?php do_action('north_after_product_list_body'); ?>
                    <?php do_action('north_before_product_list_footer'); ?>
                    <div class="products-tab__footer">
                        <div class="north-error">All products loaded</div>
                        <?php $product->get_pagination(); ?>
                    </div>
                    <?php do_action('north_after_product_list_footer'); ?>
                <?php endif; ?>
            <?php endif; ?>

        </div> <!-- end .products-tab -->

    </div>
    <div class="modal modal-delete">
        <h3>Are you sure?</h3>
        <a class="btn delete" data-id="" data-type="">Yes</a>
        <a class="btn btn-grey cancel">No</a>
        <div class="loader delete-loader"></div>
    </div>
    <!-- end #wpmdb-main -->

</div> <!-- end .wrap -->
