<?php
/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       https://northplugins.com/
 * @since       1.0
 *
 * @package    North_Checkout
 * @subpackage North_Checkout/admin/templates/tabs
 */

$display = 'none';


if( isset($_GET['tab']) && $_GET['tab'] == 'settings' ) { //phpcs:ignore WordPress.Security.NonceVerification.Recommended
    $display = 'block';
}
$state = isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] === 'on' ? "https" : "http";
if(isset($_SERVER['HTTP_HOST']) && isset($_SERVER['REQUEST_URI'])) {
    $state = urlencode($state . "://" . sanitize_text_field( $_SERVER['HTTP_HOST'] ). sanitize_text_field( $_SERVER['REQUEST_URI'] ) );
}
$licence_key = !empty(get_option('north_licence_key')) ? get_option('north_licence_key') : '';
$north_google_key = !empty(get_option('north_google_key')) ? get_option('north_google_key') : '';
$north_test_stripe = !empty(get_option('test_stripe')) ? get_option('test_stripe') : '';
$north_test_paypal = !empty(get_option('test_paypal')) ? get_option('test_paypal') : '';
$current_currency = North_Checkout_Admin::get_current_currency();

$need_reconnect_live = false;
$need_reconnect_test = false;

$paypal = new North_Checkout_Paypal();
$stripe = new North_Checkout_Stripe();

$paypal_client_live = $paypal->get_client_live();
$paypal_secret_live = $paypal->get_secret_live();
$paypal_client_test = $paypal->get_client_test();
$paypal_secret_test = $paypal->get_secret_test();

?>
<div class="wrap north-settings">

    <div class="north-tab-wrapper">
        <?php $this->plugin_tabs(); ?>
    </div>

    <?php do_action( 'north_checkout_notices' ); ?>

    <div id="wpmdb-main">
        <div id="settings-tab" class="settings-tab content-tab" >

    <?php
    if( isset($_POST['disconnect_licence']) ) { // phpcs:ignore WordPress.Security.NonceVerification.Missing
        $this->deactivate_product();
    }

    if( isset($_POST['save_settings']) ) { // phpcs:ignore WordPress.Security.NonceVerification.Missing

        if (isset($_POST['current_currency']) && !empty($_POST['current_currency'])) { // phpcs:ignore WordPress.Security.NonceVerification.Missing
            if($current_currency !== $_POST['current_currency']) { // phpcs:ignore WordPress.Security.NonceVerification.Missing
                $current_currency = sanitize_text_field( $_POST['current_currency'] ); // phpcs:ignore WordPress.Security.NonceVerification.Missing
                North_Checkout_Admin::set_current_currency($current_currency);

                $stripe->recreate_plans();
                $paypal->recreate_plans();

                echo '<div class="north-success" style="display: block;">Currency changed successfully.</div>';

            }
        }

        if (isset($_POST['north_licence_key']) && !empty($_POST['north_licence_key'])) { // phpcs:ignore WordPress.Security.NonceVerification.Missing
            $licence_key = $this->activate_product( sanitize_text_field( $_POST['north_licence_key'] ) ); // phpcs:ignore WordPress.Security.NonceVerification.Missing
        }

        if (isset($_POST['north_google_key'])) { // phpcs:ignore WordPress.Security.NonceVerification.Missing

            if($north_google_key !== $_POST['north_google_key']) { // phpcs:ignore WordPress.Security.NonceVerification.Missing
                echo '<div class="north-success" style="display: block;">Google API key are saved!</div>';
            }

            $north_google_key = $this->north_google_key_save( sanitize_text_field( $_POST['north_google_key'] ) ); // phpcs:ignore WordPress.Security.NonceVerification.Missing
        }

        if (isset($_POST['paypal_client_live'])) { // phpcs:ignore WordPress.Security.NonceVerification.Missing

            if($paypal_client_live !== $_POST['paypal_client_live']) {  // phpcs:ignore WordPress.Security.NonceVerification.Missing
                $paypal->set_client_live( sanitize_text_field( $_POST['paypal_client_live'] ) );   // phpcs:ignore WordPress.Security.NonceVerification.Missing
                $paypal_client_live = $paypal->get_client_live();
                $need_reconnect_live = true;
            }
        }

        if (isset($_POST['paypal_secret_live'])) {   // phpcs:ignore WordPress.Security.NonceVerification.Missing

            if($paypal_secret_live !== $_POST['paypal_secret_live']) {   // phpcs:ignore WordPress.Security.NonceVerification.Missing
                $paypal->set_secret_live( sanitize_text_field( $_POST['paypal_secret_live'] ) ); // phpcs:ignore WordPress.Security.NonceVerification.Missing
                $paypal_secret_live = $paypal->get_secret_live();
                $need_reconnect_live = true;
            }
        }

        if (isset($_POST['paypal_client_test'])) { // phpcs:ignore WordPress.Security.NonceVerification.Missing

            if($paypal_client_test !== $_POST['paypal_client_test']) { // phpcs:ignore WordPress.Security.NonceVerification.Missing
                $paypal->set_client_test( sanitize_text_field( $_POST['paypal_client_test'] ) ); // phpcs:ignore WordPress.Security.NonceVerification.Missing
                $paypal_client_test = $paypal->get_client_test();
                $need_reconnect_test = true;
            }
        }

        if (isset($_POST['paypal_secret_test'])) { // phpcs:ignore WordPress.Security.NonceVerification.Missing
            if($paypal_secret_test !== $_POST['paypal_secret_test']) { // phpcs:ignore WordPress.Security.NonceVerification.Missing
                $paypal->set_secret_test( sanitize_text_field($_POST['paypal_secret_test'] ) ); // phpcs:ignore WordPress.Security.NonceVerification.Missing
                $paypal_secret_test = $paypal->get_secret_test();
                $need_reconnect_test = true;
            }
        }

    }

    if (isset($_GET['code'])) { // phpcs:ignore WordPress.Security.NonceVerification.Recommended
        $stripe->connect(sanitize_text_field( $_GET['code'] ) ); // phpcs:ignore WordPress.Security.NonceVerification.Recommended
    }

    if($need_reconnect_test === true) {

        $connect = $paypal->connect('test');

        if(!empty($connect)) {
            $paypal->disconnect('test');
            echo '<div class="north-error" style="display: block;">'.esc_html($connect).'</div>';
        }else {
            echo '<div class="north-success" style="display: block;">PayPal is connected, products are synchronized!</div>';
        }
    }

    if($need_reconnect_live === true) {

        $connect = $paypal->connect('live');

        if(!empty($connect)) {
            $paypal->disconnect('live');
            echo '<div class="north-error" style="display: block;">'.esc_html($connect).'</div>';
        }else {
            echo '<div class="north-success" style="display: block;">PayPal is connected, products are synchronized!</div>';
        }
    }

    $stripe_checked = !empty(get_option('test_stripe')) ? 'checked' : '';
    $paypal_checked = !empty(get_option('test_paypal')) ? 'checked' : '';

    ?>

    <div class="settings-tab__head">
        <h2>Settings</h2>
    </div>

    <div class="settings-tab__body">
        <form id="product_edit" method="POST">
            <div class="settings-block licence-block">
                <?php if(North_Checkout_Admin::is_plugin_activated()) : ?>
                    <h3>You are already activated product</h3>
                    <label for="north_licence_key">Your key: <?php echo esc_html( substr_replace($licence_key, '*****', 0, 5) ); ?></label>
                    <input type="submit" class="btn submit-btn disconnect" name="disconnect_licence" value="Deactivate">
                <?php else :; ?>
                    <h3>North Licence</h3>
                    <label for="north_licence_key">Enter your licence</label>
                    <input type="text" id="north_licence_key" name="north_licence_key"  value="<?php echo esc_html($licence_key); ?>">
                <?php endif; ?>
            </div>
            <div class="settings-block stripe-block">
                <?php if ($account = $stripe->is_connected()) : ?>
                    <h3>You are already connected to Stripe</h3>
                    <p>Current account: <?php echo esc_html( $stripe->get_account_name($account) ); ?></p>
                    <?php if(North_Checkout_Admin::is_plugin_activated()) : ?>
                        <div class="onoffswitch">
                            <input type="checkbox" name="test_stripe" class="onoffswitch-checkbox" id="test_stripe" tabindex="0" <?php echo esc_html($stripe_checked); ?>>
                            <label class="onoffswitch-label" for="test_stripe">
                                <span class="onoffswitch-inner"></span>
                                <span class="onoffswitch-switch"></span>
                            </label>
                            <div class="loader"></div>
                        </div>
                    <?php else: ; ?>
                        <p>You can only use the test mode. To remove the restriction and start receiving payment please purchase a license.</p>
                    <?php endif; ?>
                    <a class="connect-button stripe-disconnect"><span>Disconnect</span></a>
                <?php else :; ?>
                    <h3>Connect to Stripe</h3>
                    <p>Connect your Stripe account by clicking the button below.</p>
                    <a href="https://connect.stripe.com/oauth/authorize?response_type=code&amp;client_id=ca_H6nPbsHSt2jYFVlOaHX8t9dTMVrcd0t3&amp;scope=read_write&state=<?php echo esc_html($state); ?>" class="connect-button stripe"><span>Connect with Stripe</span></a>
                <?php endif; ?>
            </div>
            <div class="settings-block paypal-block <?php echo !empty($north_test_paypal) ? ' test-mode' : 'live-mode'; ?>">

                <?php if(North_Checkout_Admin::is_plugin_activated()) : ?>

                    <?php if ($paypal->is_connected('live')) : ?>
                        <div class="paypal-live">
                            <h3>You are already connected to PayPal</h3>
                            <p>Current account: <?php echo esc_html( $paypal->get_account_name('live') ); ?></p>
                        </div>
                    <?php else: ; ?>
                        <div class="paypal-live">
                            <h3>Connect to PayPal</h3>
                            <p>Activate live mode for your PayPal account by clicking the button below. <br>You will not be able to have order bumps and upsells when using Paypal's payment method.</p>
                            <p>Read how to get your Client ID and Secret key from <a href="https://developer.paypal.com/docs/api-basics/manage-apps/#create-or-edit-sandbox-and-live-apps" target="_blank">PayPal</a></p>
                        </div>
                    <?php endif; ?>

                    <?php if ($paypal->is_connected('test')) : ?>
                        <div class="paypal-test">
                            <h3>You are already connected to PayPal Sandbox</h3>
                            <p>Current account: <?php echo esc_html( $paypal->get_account_name('test') ); ?></p>
                        </div>
                    <?php else: ; ?>
                        <div class="paypal-test">
                            <h3>Connect to PayPal Sandbox</h3>
                            <p>Activate test mode for your PayPal account by clicking the button below. <br>You will not be able to have order bumps and upsells when using Paypal's payment method.</p>
                            <p>Read how to get your Client ID and Secret key from <a href="https://developer.paypal.com/docs/api-basics/manage-apps/#create-or-edit-sandbox-and-live-apps" target="_blank">PayPal</a></p>
                        </div>
                    <?php endif; ?>

                    <div class="onoffswitch">
                        <input type="checkbox" name="test_paypal" class="onoffswitch-checkbox" id="test_paypal" tabindex="0" <?php echo esc_html( $paypal_checked ); ?>>
                        <label class="onoffswitch-label" for="test_paypal">
                            <span class="onoffswitch-inner"></span>
                            <span class="onoffswitch-switch"></span>
                        </label>
                        <div class="loader"></div>
                    </div>

                    <div class="paypal-live">
                        <label for="paypal_client_live">Client ID</label>
                        <input type="text" id="paypal_client_live" name="paypal_client_live"  value="<?php echo esc_html( $paypal_client_live ); ?>">
                        <label for="paypal_secret_live">Secret key</label>
                        <input type="password" id="paypal_secret_live" name="paypal_secret_live"  value="<?php echo esc_html( $paypal_secret_live ); ?>">
                    </div>

                    <div class="paypal-test">
                        <label for="paypal_client_test">Client ID (Sandbox)</label>
                        <input type="text" id="paypal_client_test" name="paypal_client_test"  value="<?php echo esc_html( $paypal_client_test ); ?>">
                        <label for="paypal_secret_test">Secret key (Sandbox)</label>
                        <input type="password" id="paypal_secret_test" name="paypal_secret_test"  value="<?php echo esc_html( $paypal_secret_test ); ?>">
                    </div>

                <?php else: ; ?>

                    <?php if ($paypal->is_connected('test')) : ?>
                        <div class="paypal-test">
                            <h3>You are already connected to PayPal Sandbox</h3>
                            <p>Current account: <?php echo esc_html( $paypal->get_account_name('test') ); ?></p>
                        </div>
                    <?php else: ; ?>
                        <div class="paypal-test">
                            <h3>Connect to PayPal Sandbox</h3>
                            <p>Connect your PayPal Sandbox account by clicking the button below.</p>
                        </div>
                    <?php endif; ?>

                    <p>You can only use the test mode. To remove the restriction and start receiving payment please purchase a license.</p>

                    <div class="paypal-test">
                        <label for="paypal_client_test">Client ID (Sandbox)</label>
                        <input type="text" id="paypal_client_test" name="paypal_client_test"  value="<?php echo esc_html( $paypal_client_test ); ?>">
                        <label for="paypal_client_test">Secret key (Sandbox)</label>
                        <input type="password" id="paypal_secret_test" name="paypal_secret_test"  value="<?php echo esc_html( $paypal_secret_test ); ?>">
                        <input type="hidden" name="test_paypal" class="onoffswitch-checkbox" id="test_paypal" value="<?php echo esc_html( $north_test_paypal ); ?>">
                    </div>

                <?php endif; ?>

            </div>

            <div class="settings-block sync-block">
                <h3>Sync products</h3>
                <p>Sync your products in database with Stripe and PayPal databases</p>
                <div class="loader-block">
                    <a class="btn sync-product">Start sync</a>
                    <div class="loader"></div>
                    <div class="loader-message"></div>
                </div>
            </div>

            <div class="settings-block google-block">
                <h3>Connect Google Places autocomplete</h3>
                <p>Enter your API key: (You must activate the Google Places API in the <a href="https://cloud.google.com/maps-platform/places/" target="_blank">Google Console</a>)</p>
                <input type="text" id="north_google_key" name="north_google_key"  value="<?php echo esc_html( $north_google_key ); ?>">
            </div>

            <div class="settings-block currency-block">
                <h3>Set current currency</h3>

                <div class="currency-block__wrap">
                    <p>Select the currency</p>
                    <select id="current_currency" name="current_currency">
                        <option id="USD" value="USD" <?php echo ($current_currency == "USD" || empty($current_currency)) ? 'selected' : ''; ?>>USD</option>
                        <option id="EUR" value="EUR" <?php echo ($current_currency == "EUR" || empty($current_currency)) ? 'selected' : ''; ?>>EUR</option>
                        <option id="CAD" value="CAD" <?php echo ($current_currency == "CAD" || empty($current_currency)) ? 'selected' : ''; ?>>CAD</option>
                        <option id="AUD" value="AUD" <?php echo ($current_currency == "AUD" || empty($current_currency)) ? 'selected' : ''; ?>>AUD</option>
                        <option id="DKK" value="DKK" <?php echo ($current_currency == "DKK" || empty($current_currency)) ? 'selected' : ''; ?>>DKK</option>
                        <option id="GBP" value="GBP" <?php echo ($current_currency == "GBP" || empty($current_currency)) ? 'selected' : ''; ?>>GBP</option>
                    </select>
                </div>
            </div>

            <div class="submit-wrap">
                <input type="submit" class="btn submit-btn" name="save_settings" value="Save settings">
                <div class="loader load-more__loader"></div>
            </div>
        </form>
    </div>
</div> <!-- end .settings-tab -->
    </div>
    <!-- end #wpmdb-main -->

</div> <!-- end .wrap -->
