<?php

class NorthUpsell extends ET_Builder_Module {
    function init() {
        $this->name             = esc_html__( 'North Upsell', 'et_builder' );
        $this->plural           = esc_html__( 'North Upsells', 'et_builder' );
        $this->slug             = 'north_upsell';
        $this->vb_support       = 'on';
        $this->icon             = '7';
        $this->main_css_element = '%%order_class%% .north_upsell';

        $this->custom_css_fields = array(
            'main_element' => array(
                'label'    => esc_html__( 'Main Element', 'et_builder' ),
                'no_space_before_selector' => true,
            ),
        );

        $this->settings_modal_toggles = array(
            'general'  => array(
                'toggles' => array(
                    'main_content'     => esc_html__( 'Text', 'et_builder' ),
                    'product'          => esc_html__( 'Product', 'et_builder' ),
                    'redirect'         => esc_html__( 'Redirect', 'et_builder' ),
                ),
            ),
            'advanced' => array(
                'toggles' => array(
                    'alignment'  => esc_html__( 'Alignment', 'et_builder' ),
                ),
            ),
        );

        $this->advanced_fields = array(
            'borders'               => array(
                'default' => false,
            ),
            'button'                => array(
                'button' => array(
                    'label' => esc_html__( 'Button', 'et_builder' ),
                    'css' => array(
                        'main' => $this->main_css_element,
                        'limited_main' => $this->main_css_element,
                    ),
                    'box_shadow'     => false,
                    'margin_padding' => false,
                ),
            ),
            'margin_padding' => array(
                'css' => array(
                    'padding' => $this->main_css_element, "{$this->main_css_element}:hover",
                    'margin' => $this->main_css_element,
                    'important' => 'all',
                ),
            ),
            'text'                  => false,
            'text_shadow'           => array(
                // Text Shadow settings are already included on button's advanced style
                'default' => false,
            ),
            'box_shadow'     => array(
                'default' => array(
                    'css' => array(
                        'main'      => implode( ', ', array(
                            '%%order_class%% .north_upsell',
                        ) ),
                        'important' => true,
                    ),
                ),
            ),
            'background'            => false,
            'fonts'                 => false,
            'max_width'             => false,
            'height'                => false,
            'link_options'          => false,
            'position_fields'       => array(
                'css' => array(
                    'main'=> $this->main_css_element,
                ),
            ),
            'transform'             => array(
                'css' => array(
                    'main' => $this->main_css_element,
                ),
            ),
        );

        $this->help_videos = array(
            array(
                'id'   => esc_html( 'XpM2G7tQQIE' ),
                'name' => esc_html__( 'An introduction to the Button module', 'et_builder' ),
            ),
        );
    }

    function get_fields() {

        $north_product = new North_Checkout_Product();
        $products = $north_product->get_products(-1, true) !== "error" ? $north_product->get_products(-1, true) : null;

        $fields = array(
            'use_redirect'       => array(
                'label'            => esc_html__( 'Enable Redirect URL', 'et_builder' ),
                'type'             => 'yes_no_button',
                'option_category'  => 'configuration',
                'options'          => array(
                    'off' => esc_html__( 'No', 'et_builder' ),
                    'on'  => esc_html__( 'Yes', 'et_builder' ),
                ),
                'affects'          => array(
                    'redirect_url',
                ),
                'toggle_slug'      => 'redirect',
                'description'      => esc_html__( 'Redirect users after successful form submission.', 'et_builder' ),
                'default_on_front' => 'off',
            ),
            'redirect_url'       => array(
                'label'           => esc_html__( 'Redirect URL', 'et_builder' ),
                'type'            => 'text',
                'option_category' => 'configuration',
                'depends_show_if' => 'on',
                'toggle_slug'     => 'redirect',
                'description'     => esc_html__( 'Type the Redirect URL', 'et_builder' ),
            ),
            'button_text' => array(
                'label'            => esc_html__( 'Button upsell text', 'et_builder' ),
                'type'             => 'text',
                'option_category'  => 'basic_option',
                'description'      => esc_html__( 'Input your upsell button text.', 'et_builder' ),
                'toggle_slug'      => 'main_content',
                'dynamic_content'  => 'text',
                'mobile_options'   => true,
                'hover'            => 'tabs',
            ),
            'button_alignment' => array(
                'label'            => esc_html__( 'Button Alignment', 'et_builder' ),
                'description'      => esc_html__( 'Align your button to the left, right or center of the module.', 'et_builder' ),
                'type'             => 'text_align',
                'option_category'  => 'configuration',
                'options'          => et_builder_get_text_orientation_options( array( 'justified' ) ),
                'tab_slug'         => 'advanced',
                'toggle_slug'      => 'alignment',
                'mobile_options'   => true,
            ),
            'product_item'      => array(
                'label'            => esc_html__( 'Product', 'et_builder' ),
                'type'             => 'select',
                'option_category'  => 'basic_option',
                'description'      => esc_html__( 'Here you can select the Product.', 'et_builder' ),
                'searchable'       => true,
                'options'          => $products,
                'toggle_slug'     => 'product',
            ),
        );

        return $fields;
    }

    /**
     * Get button alignment.
     *
     * @since 3.23 Add responsive support by adding device parameter.
     *
     * @param  string $device Current device name.
     * @return string         Alignment value, rtl or not.
     */
    public function get_button_alignment( $device = 'desktop' ) {
        $suffix           = 'desktop' !== $device ? "_{$device}" : '';
        $text_orientation = isset( $this->props["button_alignment{$suffix}"] ) ? $this->props["button_alignment{$suffix}"] : '';

        return et_pb_get_alignment( $text_orientation );
    }

    public function get_transition_fields_css_props() {
        return array();
    }

    function render( $attrs, $content = null, $render_slug ) {
        $multi_view                      = et_pb_multi_view_options( $this );
        $use_redirect                    = $this->props['use_redirect'];
        $redirect_url                    = $this->props['redirect_url'];
        $product_item                    = $this->props['product_item'];
        $button_text                     = $this->_esc_attr( 'button_text', 'limited' );
        $button_custom                   = $this->props['custom_button'];

        $button_alignment                = $this->get_button_alignment();
        $is_button_aligment_responsive   = et_pb_responsive_options()->is_responsive_enabled( $this->props, 'button_alignment' );
        $button_alignment_tablet         = $is_button_aligment_responsive ? $this->get_button_alignment( 'tablet' ) : '';
        $button_alignment_phone          = $is_button_aligment_responsive ? $this->get_button_alignment( 'phone' ) : '';

        $custom_icon_values              = et_pb_responsive_options()->get_property_values( $this->props, 'button_icon' );
        $custom_icon                     = isset( $custom_icon_values['desktop'] ) ? $custom_icon_values['desktop'] : '';
        $custom_icon_tablet              = isset( $custom_icon_values['tablet'] ) ? $custom_icon_values['tablet'] : '';
        $custom_icon_phone               = isset( $custom_icon_values['phone'] ) ? $custom_icon_values['phone'] : '';

        // Button Alignment.
        $button_alignments = array();
        if ( ! empty( $button_alignment ) ) {
            array_push( $button_alignments, sprintf( 'et_pb_button_alignment_%1$s', esc_attr( $button_alignment ) ) );
        }

        if ( ! empty( $button_alignment_tablet ) ) {
            array_push( $button_alignments, sprintf( 'et_pb_button_alignment_tablet_%1$s', esc_attr( $button_alignment_tablet ) ) );
        }

        if ( ! empty( $button_alignment_phone ) ) {
            array_push( $button_alignments, sprintf( 'et_pb_button_alignment_phone_%1$s', esc_attr( $button_alignment_phone ) ) );
        }

        $button_alignment_classes = join( ' ', $button_alignments );

        // Nothing to output if neither Button Text nor Button URL defined
        $redirect_url = trim( $redirect_url );

        if ( '' === $button_text && '' === $redirect_url ) {
            return '';
        }

        // Background layout data attributes.
        $data_background_layout = et_pb_background_layout_options()->get_background_layout_attrs( $this->props );

        // Background layout class names.
        $background_layout_class_names = et_pb_background_layout_options()->get_background_layout_class( $this->props );
        $this->add_classname( $background_layout_class_names );

        // Module classnames
        $this->remove_classname( 'et_pb_module' );
        $this->remove_classname( 'north_upsell' );

        $button = '';

        if( !isset($_COOKIE['customer_id']) ) {
            $button = 'This is a one click upsell and cannot be purchased without having purchased an item.';
        }else {

            $icon_class = '';
            if ( ( '' !== $custom_icon || '' !== $custom_icon_tablet || '' !== $custom_icon_phone ) && 'on' === $button_custom ) {
                $icon_class = 'et_pb_custom_button_icon';
            }

            // Custom icon data attribute
            $use_data_icon = '' !== $custom_icon && 'on' === $button_custom;
            $data_icon     = $use_data_icon ? sprintf(
                ' data-icon="%1$s"',
                esc_attr( et_pb_process_font_icon( $custom_icon ) )
            ) : '';

            $use_data_icon_tablet = '' !== $custom_icon_tablet && 'on' === $button_custom;
            $data_icon_tablet     = $use_data_icon_tablet ? sprintf(
                ' data-icon-tablet="%1$s"',
                esc_attr( et_pb_process_font_icon( $custom_icon_tablet ) )
            ) : '';

            $use_data_icon_phone = '' !== $custom_icon_phone && 'on' === $button_custom;
            $data_icon_phone     = $use_data_icon_phone ? sprintf(
                ' data-icon-phone="%1$s"',
                esc_attr( et_pb_process_font_icon( $custom_icon_phone ) )
            ) : '';

            $button = sprintf(
                '<a class="north_upsell et_pb_button %1$s %2$s" data-product="%3$s" data-redirect="%4$s" %6$s%7$s%8$s>%5$s<div class="loader"></div></a>',
                    $this->module_classname( $render_slug ),
                    $icon_class,
                    $product_item,
                    $redirect_url,
                    $button_text,
                    et_core_esc_previously( $data_icon ),
                    et_core_esc_previously( $data_icon_tablet ),
                    et_core_esc_previously( $data_icon_phone )
            );
        }

        // Render module output
        $output = sprintf(
            '<div class="et_pb_button_module_wrapper %3$s_wrapper %2$s et_pb_module "%4$s>
				%1$s
			</div>',
            $button,
            esc_attr( $button_alignment_classes ),
            esc_attr( ET_Builder_Element::get_module_order_class( $this->slug ) ),
            et_core_esc_previously( $data_background_layout )
        );

        $transition_style = $this->get_transition_style( array( 'all' ) );
        self::set_style( $render_slug, array(
            'selector'    => '%%order_class%% .north_upsell, %%order_class%% .north_upsell:after',
            'declaration' => esc_html( $transition_style ),
        ) );

        // Tablet.
        $transition_style_tablet = $this->get_transition_style( array( 'all' ), 'tablet' );
        if ( $transition_style_tablet !== $transition_style ) {
            self::set_style( $render_slug, array(
                'selector'    => '%%order_class%% .north_upsell, %%order_class%% .north_upsell:after',
                'declaration' => esc_html( $transition_style_tablet ),
                'media_query' => ET_Builder_Element::get_media_query( 'max_width_980' ),
            ) );
        }

        // Phone.
        $transition_style_phone = $this->get_transition_style( array( 'all' ), 'phone' );
        if ( $transition_style_phone !== $transition_style || $transition_style_phone !== $transition_style_tablet ) {
            self::set_style( $render_slug, array(
                'selector'    => '%%order_class%% .north_upsell, %%order_class%% .north_upsell:after',
                'declaration' => esc_html( $transition_style_phone ),
                'media_query' => ET_Builder_Element::get_media_query( 'max_width_767' ),
            ) );
        }

        return $output;
    }

    /**
     * Filter multi view value.
     *
     * @since 3.27.1
     *
     * @see ET_Builder_Module_Helper_MultiViewOptions::filter_value
     *
     * @param mixed $raw_value Props raw value.
     * @param array $args {
     *     Context data.
     *
     *     @type string $context      Context param: content, attrs, visibility, classes.
     *     @type string $name         Module options props name.
     *     @type string $mode         Current data mode: desktop, hover, tablet, phone.
     *     @type string $attr_key     Attribute key for attrs context data. Example: src, class, etc.
     *     @type string $attr_sub_key Attribute sub key that availabe when passing attrs value as array such as styes. Example: padding-top, margin-botton, etc.
     * }
     * @param ET_Builder_Module_Helper_MultiViewOptions $multi_view Multiview object instance.
     *
     * @return mixed
     */
    public function multi_view_filter_value( $raw_value, $args, $multi_view ) {
        $name    = isset( $args['name'] ) ? $args['name'] : '';
        $mode    = isset( $args['mode'] ) ? $args['mode'] : '';
        $context = isset( $args['context'] ) ? $args['context'] : '';

        $fields_need_escape = array(
            'title',
        );

        if ( $raw_value && 'content' === $context && in_array( $name, $fields_need_escape, true ) ) {
            return $this->_esc_attr( $multi_view->get_name_by_mode( $name, $mode ), 'none', $raw_value );
        }

        return $raw_value;
    }
}

new NorthUpsell;