var placeSearch, autocomplete, useGmaps = false;

var componentForm = {
	street_number: 'short_name',
	route: 'long_name',
	locality: 'long_name',
	administrative_area_level_1: 'short_name',
	country: 'long_name',
	postal_code: 'short_name'
};

function initAutocomplete() {

	if (typeof google === 'undefined') {
		return;
	}

	var service = new google.maps.places.AutocompleteService();
	service.getPlacePredictions({
			input: 'Brisbane,Australia',
			types: ['(cities)']
		},
		function(predictions, status) {
			if (status === google.maps.places.PlacesServiceStatus.OK) {
				useGmaps = true; /* status is ok so set flag to use Google Maps */
			}
		});

	if (useGmaps === true && typeof(google) !== 'undefined') {
		autocomplete = new google.maps.places.Autocomplete(
			jQuery('.checkout_field_address .input_autocomplete')[0], {types: ['geocode']});

		// Avoid paying for data that you don't need by restricting the set of
		// place fields that are returned to just the address components.
		autocomplete.setFields(['address_component']);

		// When the user selects an address from the drop-down, populate the
		// address fields in the form.
		autocomplete.addListener('place_changed', fillInAddress);
	}
}

function fillInAddress() {

	var place = autocomplete.getPlace();
	let country, city, state, postal, street, street_number;

	for (var i = 0; i < place.address_components.length; i++) {
		if (place.address_components[i].types[0] === 'locality') {
			city = place.address_components[i]['long_name'];
		}

		if (place.address_components[i].types[0] === 'country') {
			country = place.address_components[i]['long_name'];
		}

		if (place.address_components[i].types[0] === 'postal_code') {
			postal = place.address_components[i]['short_name'];
		}

		if (place.address_components[i].types[0] === 'administrative_area_level_1') {
			state = place.address_components[i]['long_name'];
		}

		if (place.address_components[i].types[0] === 'route') {
			street = place.address_components[i]['short_name'];
		}

		if (place.address_components[i].types[0] === 'street_number') {
			street_number = place.address_components[i]['short_name'];
		}

		jQuery('.input_autocomplete input').val(street_number + ' ' + street);
		jQuery('.input_city input').val(city);
		jQuery('.input_country input').val(country);
		jQuery('.input_zip input').val(postal);
		jQuery('.input_state input').val(state);

	}
}

// Bias the autocomplete object to the user's geographical location,
// as supplied by the browser's 'navigator.geolocation' object.
function geolocate() {
	if (navigator.geolocation) {
		navigator.geolocation.getCurrentPosition(function(position) {
			var geolocation = {
				lat: position.coords.latitude,
				lng: position.coords.longitude
			};
			var circle = new google.maps.Circle(
				{center: geolocation, radius: position.coords.accuracy});
			autocomplete.setBounds(circle.getBounds());
		});
	}
}

function numberWithCommas(x) {
	if(x) {
		var parts = x.toString().split(".");
		parts[0] = parts[0].replace(/\B(?=(\d{3})+(?!\d))/g, ",");

		if(!parts[1]) {
			return parts.join(".") + '.00';
		}

		if(parts[1].length === 1) {
			return parts.join(".") + '0';
		}

		return parts.join(".");
	}else {
		return false;
	}
}

function validateEmail(email) {
	const re = /^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
	return re.test(String(email).toLowerCase());
}

function update_total() {

	let total = null;
	let product = document.querySelector('.checkout_field_product');
	let product_price = '';
	let variable_product = document.querySelector('.variation-price-change');
	let bump_product = document.getElementById('checkout_bump');
	let bump = null;
	let price = null;

	if(product) {

		if(product.classList.contains('checkout_field_dynamic_product')) {
			product_price = document.querySelector('.checkout_field_product #product_single_price');

			if(product_price) {
				total = parseFloat(product_price.value);
			}

		}else {
			product_price = document.querySelector('.checkout_field_product #product_single_price .value');

			if(product_price) {
				total = parseFloat(product_price.innerHTML);
			}
		}
	}

	// if(variable_product) {
	//
	// 	var tagName = variable_product.tagName.toLowerCase();
	//
	// 	if (tagName === 'input') {
	// 		price = parseFloat(variable_product.getAttribute("data-price"));
	// 	}else {
	// 		price = parseFloat(variable_product.options[variable_product.selectedIndex].getAttribute("data-price"));
	// 	}
	//
	// 	total = price;
	// }

	if(bump_product && bump_product.checked === true) {
		bump = parseFloat(bump_product.getAttribute("data-price"));
		total += bump;
	}

	let total_val = document.querySelector('.checkout_total .value');
	let subtotal_val = document.querySelector('.checkout_total .subtotal-value');
	let total_origin = document.querySelector('.checkout_total .price');

	if(total_origin) {
		total_origin.setAttribute("data-origin", total);
	}

	if(total_val && total) {
		total_val.innerHTML = numberWithCommas(total.toFixed(2));
		subtotal_val.innerHTML = numberWithCommas(total.toFixed(2));
	}

}

function check_discount(type, value, price) {

	if(type == 'fixed') {
		price = price - value;
	}else {
		var percent = price / 100 * value;
		price = price - percent;
	}

	return price > 0 ? price : 0;
}

function init_multiple_products() {

	var products = jQuery(".checkout_field_product").length;
	let first_product = jQuery('#payment-form .checkout_field_product').first();
	jQuery('#product_module').val(first_product.find('.checkout_product').data("module"));

	jQuery('#payment-form .checkout_product .checkout_product_data').prop("checked", false);
	first_product.find('.checkout_product_data').prop("checked", true);
	first_product.find('.checkout_product').addClass("active");
	jQuery('#payment-form .checkout_product').addClass("multiple");

}

function paypalReload() {
	paypalDestroy();
	paypalInit();
}

function remove_coupon(total, error) {
	jQuery('#card-errors').show().html(error);
	jQuery('html, body').animate({
		scrollTop: jQuery("#card-errors").offset().top - 150
	}, 500);

	setTimeout(function() {
		$("#card-errors").hide()
	}, 5000);

	jQuery('.checkout_total .subtotal').hide();
	jQuery('#checkout_discount_input').val('');
	jQuery('#total_price').text(numberWithCommas(total.toFixed(2)));
}

jQuery(document).ready(function( $ ) {

	update_total();
	init_multiple_products();
	paypalInit();

	$('.apply-coupon').click(function(e) {
		e.preventDefault();

		let that = $(this);
		let coupon = that.parent().find('.checkout-coupon').val();
		let current_product = $('.checkout_product.active .checkout_product_data').data("type");

		if(current_product !== 'One time') {
			$('#card-errors').show().html("Coupon cannot be used with Subscriptions and Payment Plans! Available product types for coupon: Single, Dynamic, Variable.");
			$('html, body').animate({
				scrollTop: $("#card-errors").offset().top - 150
			}, 500);
			setTimeout(function() {
				$("#card-errors").hide();
			}, 5000);

			return;
		}

		$.ajax({
			type: 'POST',
			url: ajax_object.ajaxurl,
			data: {
				'action': 'apply_coupon',
				'coupon': coupon,
			},
			beforeSend: function() {
				that.find('.loader').show();
			},
			success: function (data) {
				that.find('.loader').hide();

				if(data.success === false) {

					let total = $('.total-block .price').data('origin');
					remove_coupon(total, data.data);

				}else {
					$('.discount-label-help').text("(" + coupon + ")");
					$('.discount-price').html(data.data.html);
					$('.checkout_total .subtotal .discount-price').data('type', data.data.type);
					$('.checkout_total .subtotal .discount-price').data('value', data.data.price);

					$('.checkout_total .subtotal').show();
					$('#checkout_discount_input').val(coupon);

					let total = $('#subtotal_price').text().replace(',', '');
					total = check_discount(data.data.type, data.data.price, total);
					$('#total_price').text(numberWithCommas(total.toFixed(2)));

				}
			}
		});

	});

	$('.qty-input .qty-minus').on("click", function() {
		let input = $(this).parent().find('input');
		let input_val = parseInt(input.val());
        let current_product_price = parseFloat($(this).closest('.checkout_product').find('#product_single_price').data('price'));

		if(input_val === 1) {
			return;
		}

		input.val(--input_val);

        let total = current_product_price * input_val;
        $(this).closest('.checkout_product').find('#product_single_price .value').text(numberWithCommas(total.toFixed(2)));
	});

	$('.qty-input .qty-plus').on("click", function() {
		let input = $(this).parent().find('input');
		let input_val = parseInt(input.val());
        let current_product_price = parseFloat($(this).closest('.checkout_product').find('#product_single_price').data('price'));

		input.val(++input_val);

        let total = current_product_price * input_val;
        $(this).closest('.checkout_product').find('#product_single_price .value').text(numberWithCommas(total.toFixed(2)));
	});

	$('.qty-input input').on("change", function() {
		let input = $(this).parent().find('input');
		let input_val = parseInt(input.val());
		let current_product_price = parseFloat($(this).closest('.checkout_product').find('#product_single_price').data('price'));
		let total = current_product_price * input_val;

        $(this).closest('.checkout_product').find('#product_single_price .value').text(numberWithCommas(total.toFixed(2)));

		$('.checkout_total .price').data("origin", total);

		if($('.checkout_order_bump input').is(":checked")) {
			total += parseFloat(jQuery('.checkout_order_bump input').data("price"));
		}

		$('#total_price').text(numberWithCommas(total.toFixed(2)));
	});

	$( "#payment-form input.text-input" ).change(function(e) {

		$('#payment-form .condition_field').each(function(e){
			let ralation = $(this).data("conditional-relation");
			let logic = $(this).data("conditional-logic");


			for (let i = 0; i < logic.length; i++) {
				let field_value = $('.condition_field[data-original_id=' + logic[i][0] + ']').val();
				let cond = logic[i][1];
				let need_value = logic[i][2];

				if (cond === "is") {
					if (field_value === need_value) {

					}
				}else if(cond === "not is") {

				}

			}
		});

	});

	$('#payment-form').on('submit', async function(e) {
		let that = $(this);
		e.preventDefault();

		if(that.hasClass('loaded')) {
			return;
		}

		let error_message = '',
			error_stripe,
			valid = true;

		var element = document.querySelector("#card-element");

		if(element) {
			error_stripe = await stripe.createToken(card).then(function (result) {
				if (result.error) {
					valid = false;
					return '<li>Card number is invalid</li>';
				} else {
					// Send the token to your server.
					stripeTokenHandler(result.token);
					valid = true;
				}
			});
		}

		$(this).find('.checkout_field .required').each(function(){

			if($(this).val() === '') {
				$(this).addClass("et_checkout_error");
				valid = false;
				error_message += '<li>' + $(this).attr("placeholder") + '</li>';
			}
		});

		$(this).find('.checkout_field input[pattern]').each(function(){

			let pattern = new RegExp($(this).attr("pattern"));

			if(!pattern.test(String($(this).val()))) {
				$(this).addClass("et_checkout_error");
				valid = false;
				error_message += '<li>' + $(this).attr("placeholder") + ' (' + $(this).attr("title") + ' )</li>';
			}
		});

		$(this).find('.checkout_field_email #checkout_email_email').each(function(){
			if($(this).val() !== '' && !validateEmail($(this).val())) {
				$(this).addClass("et_checkout_error");
				valid = false;
				error_message += '<li>Email address not valid</li>';
			}
		});

		if($(this).find('.checkout_product.active').hasClass('disabled')) {
			valid = false;
			error_message += '<li>This product is out of stock</li>';
		}

		if(valid) {

			let form = $(this).serialize();

			$.ajax({
				type: 'POST',
				url: ajax_object.ajaxurl,
				data: {
					'action': 'stripe_payment_process',
					'form': form,
				},
				beforeSend: function() {
					that.find('.checkout_submit').addClass("loading");
				},
				success: function (data) {
					that.find('.checkout_submit').removeClass("loading");

					if(data) {
						$('#card-errors').show().html(data);
						$('html, body').animate({
							scrollTop: $("#card-errors").offset().top - 150
						}, 500);

						setTimeout(function() {
							$("#card-errors").hide()
						}, 5000);

					}else {
						$('#card-errors').hide();
						if(that.data("redirect") === '') {
							$('.modal-checkout').fadeIn('fast');
							$('#payment-form').addClass('loaded');
						}else {
							window.location.href = that.data("redirect");
						}
					}
				}
			});

		}else {
			$('#card-errors').show().html('<p>Please, fill in the following fields:</p><ul>' + error_message + error_stripe + '</ul>');
			$('html, body').animate({
				scrollTop: $("#card-errors").offset().top - 150
			}, 500);
			setTimeout(function() {
				$("#card-errors").hide()
			}, 5000);
		}

	});

	$('.variation-price-change').change(function(){

		let total, module_num;

		if($(this).is("input")) { /*If input*/
			total = parseFloat($(this).data('price'));
			module_num = $(this).data('module-num');
            $('.product_' + module_num + ' #product_single_price').data('price', numberWithCommas(total.toFixed(2)));
            $(this).closest('.checkout_product').find('#product_single_price .value').text(numberWithCommas(total.toFixed(2)));

			if($(this).closest('.checkout_product').find('.quantity-wrapper').length > 0){ /*If quantity present*/
				let qty = $(this).closest('.checkout_product').find('.qty-input input').val();
                total = total * parseInt(qty);
                $(this).closest('.checkout_product').find('#product_single_price .value').text(numberWithCommas(total.toFixed(2)));
			}
		}else { /*If other (ets. select)*/
			total = parseFloat($(this).find(':selected').attr('data-price'));
			module_num = parseFloat($(this).find(':selected').attr('data-module-num'));
            $('.product_' + module_num + ' #product_single_price').data('price', numberWithCommas(total.toFixed(2)));
            $(this).closest('.checkout_product').find('#product_single_price .value').text(numberWithCommas(total.toFixed(2)));
		}


		if(!total) {
			return;
		}

		let origin_total = total;

		if($('.checkout_order_bump input').is(":checked")) {
			total += parseFloat($('.checkout_order_bump input').data("price"));
		}

		if($('.product_' + module_num + ' .checkout_product_data').is(":checked")) {
			$('.checkout_total .price').data("origin", origin_total);

			$('.checkout_total .value').text(numberWithCommas(total.toFixed(2)));
			$('.checkout_total .subtotal-value').text(numberWithCommas(total.toFixed(2)));
		}
	});

	$('body').on("change", ".checkout_order_bump input", function(){
		let bump = $(this).data("price");
		let current_price = $('.checkout_total .price').data("origin");
		let total = parseFloat(bump) + parseFloat(current_price);

		if( $(this).is(":checked") ) {
			$('.checkout_total .subtotal-value').text(numberWithCommas(total.toFixed(2)));

			if($('#checkout_discount_input').val() !== '' && $('#checkout_discount_input').val() != undefined) {
				let disc_type = $('.checkout_total .subtotal .discount-price').data('type');
				let disc_price = $('.checkout_total .subtotal .discount-price').data('value');

				total = check_discount(disc_type, disc_price, total);
			}

			$('.checkout_total .value').text(numberWithCommas(total.toFixed(2)));
			$(this).parent().parent().addClass("checked");
		}else {

			let clear_price = $('.checkout_total .price').data("origin");
			$('.checkout_total .subtotal-value').text(numberWithCommas(clear_price.toFixed(2)));

			let origin = $('.checkout_total .price').data("origin");

			if($('#checkout_discount_input').val() !== '' && $('#checkout_discount_input').val() != undefined) {
				let disc_type = $('.checkout_total .subtotal .discount-price').data('type');
				let disc_price = $('.checkout_total .subtotal .discount-price').data('value');

				origin = check_discount(disc_type, disc_price, origin);
			}

			$('.checkout_total .value').text(numberWithCommas(origin.toFixed(2)));
			$(this).parent().parent().removeClass("checked");
		}
	});

	$('.modal-close').click(function(){
		window.location.reload();
	});

	$('.checkout_product').on("click", function() {

		let product = $(this);

		$('#product_module').val(product.data("module"));

		$('#payment-form .checkout_product .checkout_product_data').prop("checked", false);
		$(product).find(".checkout_product_data").prop("checked", true);

		$('.checkout_product').removeClass("active");
		$(product).toggleClass("active");

        let total = parseFloat($(product).find('.price').data('price'));

		if($(product).hasClass('checkout_dynamic')) {
			total = parseFloat($(product).find("#product_single_price").val());
		}

		let qty = $(product).find('.qty-input input').val();

		if(qty) {
			total = total * parseInt(qty);
		}

		$('.checkout_total .price').data("origin", total);

        $(this).closest('.checkout_product').find('#product_single_price .value').text(numberWithCommas(total.toFixed(2)));

		if($('.checkout_order_bump input').is(":checked")) {
			total += parseFloat($('.checkout_order_bump input').data("price"));
		}

		$('.checkout_total .subtotal-value').text(numberWithCommas(total.toFixed(2)));

		if($('#checkout_discount_input').val() !== '' && $('#checkout_discount_input').val() != undefined) {

			if($(product).find(".checkout_product_data").data("type") != 'One time') {
				remove_coupon(total, "Coupon cannot be used with Subscriptions and Payment Plans! Available product types for coupon: Single, Dynamic, Variable.<br>Coupon was removed!");
			}else {
				let disc_type = $('.checkout_total .subtotal .discount-price').data('type');
				let disc_price = $('.checkout_total .subtotal .discount-price').data('value');

				total = check_discount(disc_type, disc_price, total);
			}
		}

		$('.checkout_total .value').text(numberWithCommas(total.toFixed(2)));

		paypalReload();

		if(product.hasClass('disabled')) {
			$('#paypal-buttons').css("pointer-events", "none");
		}else {
			$('#paypal-buttons').css("pointer-events", "all");
		}

	});

	$('input#product_single_price').on("change", function() {

		let total = parseFloat($(this).val());

		$('.checkout_total .price').data("origin", total);

		if($('.checkout_order_bump input').is(":checked")) {
			total += parseFloat($('.checkout_order_bump input').data("price"));
		}

		$('.checkout_total .subtotal-value').text(numberWithCommas(total.toFixed(2)));

		if($('#checkout_discount_input').val() !== '' && $('#checkout_discount_input').val() != undefined) {
			let disc_type = $('.checkout_total .subtotal .discount-price').data('type');
			let disc_price = $('.checkout_total .subtotal .discount-price').data('value');

			total = check_discount(disc_type, disc_price, total);
		}

		$('.checkout_total .value').text(numberWithCommas(total.toFixed(2)));

		paypalReload();

	});

	$('.north_upsell').click(function(){

		let that = $(this);
		let product = $(this).data("product");
		let redirect = $(this).data("redirect");

		$.ajax({
			type: 'POST',
			url: ajax_object.ajaxurl,
			data: {
				'action': 'payment_upsell',
				'product': product
			},
			beforeSend: function() {
				that.find('.loader').show();
			},
			success: function (data) {
				that.find('.loader').hide();
				$('.modal-errors').html(data);

				if(redirect === '') {
					$('.modal-checkout').fadeIn('fast');
				}else {
					window.location.href = redirect;
				}
			}
		});

	});

});